@@ -8,7 +8,7 @@ use File::Path;
 use BackPAN::Index;
 
 use base "Exporter";
-our @EXPORT = qw(new_backpan new_pbp);
+our @EXPORT = qw(new_backpan new_pbp cache_dir clear_cache);
 
 
 # The local cache directory for testing
@@ -27,35 +27,42 @@ sub clear_cache {
 # use the local one that comes with the distribution.
 use URI::file;
 use File::Spec::Unix;
-my $remote_index = "http://www.astray.com/tmp/backpan.txt.gz";
-my $local_index  = URI::file->new( File::Spec::Unix->rel2abs("t/backpan.txt.gz") );
+my $local_index_url  = URI::file->new( File::Spec::Unix->rel2abs("t/backpan.txt.gz") );
+
 sub backpan_index_url {
     use LWP::Simple;
-    return $local_index if $ENV{BACKPAN_INDEX_TEST_NO_INTERNET};
-    return head($remote_index) ? $remote_index : $local_index;
+
+    return $local_index_url if $ENV{BACKPAN_INDEX_TEST_NO_INTERNET};
+
+    my $remote_index_url = BackPAN::Index->default_backpan_index_url;
+    return head($remote_index_url) ? $remote_index_url : $local_index_url;
+}
+
+sub backpan_index_arg {
+    return backpan_index_url => backpan_index_url();
 }
 
 
 # Init a new BackPAN::Index object with the right options for testing
 sub new_backpan {
     my %args = @_;
-    $args{backpan_index_url} = backpan_index_url() if $args{update};
 
     return BackPAN::Index->new({
         cache_dir               => cache_dir(),
         update                  => 0,
+	backpan_index_arg(),
         %args
     });
 }
 
 sub new_pbp {
     my %args = @_;
-    $args{backpan_index_url} = backpan_index_url() if $args{update};
 
     require Parse::BACKPAN::Packages;
     return Parse::BACKPAN::Packages->new({
         cache_dir               => cache_dir(),
         update                  => 0,
+	backpan_index_arg(),
         %args
     });
 }
